(function ($, Drupal) {

  'use strict';

  Drupal.behaviors.jsnlog = {
    logger: null,
    attach: function (context, settings) {
      // Check if library is present.
      if (typeof JL == 'undefined') {
        return;
      }
      // Attach event error handler.
      this.initEventErrorHandler();
      // Setup JSNLog with user settings.
      this.initLogger(settings.jsnlog, settings.path.baseUrl);
    },
    initEventErrorHandler: function () {
      // Override error handler with own.
      if (typeof window !== 'undefined') {
        window.onerror = function (errorMsg, url, lineNumber, column, errorObj) {
          JL('drupalOnErrorLogger').fatalException({
            '@msg': 'Uncaught Exception',
            '@errorMsg': errorMsg ? (errorMsg.message || errorMsg) : '',
            '@url': url,
            '@line_number': lineNumber,
            '@column': column,
            'stack': errorObj.stack,
            '@href': location.href,
            '@windowWidth': window.innerWidth,
            '@windowHeight': window.innerHeight,
            '@windowPositionX': window.pageXOffset,
            '@windowPositionY': window.pageYOffset
          });
          // Tell browser to run its own error handler as well
          return false;
        };
      }
    },
    initLogger: function (settings, baseUrl) {
      if (this.logger == null) {
        var appenderOptions = {
          level: settings.debug_level
        };
        var appenders = [];

        if (settings.user_agent_regex.length) {
          appenderOptions.userAgentRegex = settings.user_agent_regex;
        }

        JL.setOptions({
          defaultAjaxUrl: settings.defaultAjaxUrl,
          defaultBeforeSend: this.beforeSend
        });
        this.logger = JL('defaultJSNLog');

        if (settings.logging_type === 'all' || settings.logging_type === 'console') {
          appenders.push(
            this.initAppender('ConsoleAppender', appenderOptions)
          );
        }

        if (settings.logging_type === 'all' || settings.logging_type === 'ajax') {
          appenders.push(
            this.initAppender('AjaxAppender', appenderOptions)
          );
        }

        this.logger.setOptions({
          appenders: appenders
        });
      }
    },
    initAppender: function (appenderName, appenderOptions) {
      var appender = JL.createConsoleAppender(appenderName);
      appender.setOptions(appenderOptions);

      return appender;
    },
    beforeSend: function (xhr, json) {
      // Provide the whole url to pass queries and # as well.
      json.href = location.href;
    },
    test: function (e) {
      e.preventDefault();
      throw 'JSNLog test exception';
    }
  };
})(jQuery, Drupal);
