<?php

namespace Drupal\Tests\jsnlog\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Test jsnlog settings form.
 *
 * @group jsnlog
 */
class JSNLogHelpTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stable';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['jsnlog', 'help'];

  /**
   * A simple user.
   *
   * @var \Drupal\user\Entity\User
   */
  private $user;

  /**
   * {@inheritdoc}
   */
  protected function setUp():void {
    parent::setup();

    $this->user = $this->drupalCreateUser([
      'access administration pages',
      'administer jsnlog',
    ]);
  }

  /**
   * Test help page.
   */
  public function testHelpPage() {
    $this->drupalLogin($this->user);

    $path = Url::fromRoute('help.page', ['name' => 'jsnlog']);
    $this->drupalGet($path);

    $statusCode = $this->getSession()->getDriver()->getClient()->getResponse()->getStatusCode();
    $this->assertEquals(200, $statusCode);

    $this->assertSession()->pageTextContains('JSNLog');
  }

  /**
   * Test block text.
   */
  public function testBlockHelp() {
    $this->drupalLogin($this->user);

    $route_name = 'jsnlog.settings.form';
    $path = Url::fromRoute($route_name);
    $this->drupalGet($path);
    $route_match = $this->container->get('current_route_match');

    $statusCode = $this->getSession()->getDriver()->getClient()->getResponse()->getStatusCode();
    $this->assertEquals(200, $statusCode);

    // Avoid to place help block.
    $output = jsnlog_help($route_name, $route_match);

    $this->assertStringContainsString('Debug Level', $output);
  }

}
